//-----------------------------------------------------------------------------
// Torque Game Engine 
// Copyright (C) GarageGames.com, Inc.
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Load up defaults console values.

exec("./defaults.cs");

//-----------------------------------------------------------------------------


   // All mods need the random seed set
   //setRandomSeed();

   // Very basic functions used by everyone
   exec("./client/canvas.cs");
   exec("./client/audio.cs");


function initBaseClient()
{
   // Base client functionality
   exec("./client/message.cs");
   exec("./client/mission.cs");
   exec("./client/missionDownload.cs");
   exec("./client/actionMap.cs");
   exec("./client/extras.cs");

   // There are also a number of support scripts loaded by the canvas
   // when it's first initialized.  Check out client/canvas.cs
}

function initBaseServer()
{
   // Base server functionality
   exec("./server/audio.cs");
   exec("./server/server.cs");
   exec("./server/message.cs");
   exec("./server/commands.cs");
   exec("./server/missionInfo.cs");
   exec("./server/missionLoad.cs");
   exec("./server/missionDownload.cs");
   exec("./server/clientConnection.cs");
   exec("./server/kickban.cs");
   exec("./server/game.cs");
}   


//-----------------------------------------------------------------------------
function generateBigChunkTest(%buffSize, %chunkCount)
{
   $chunkStartTime = getRealTime();
   
   $chunkTestLevel = 10;
   $chunkCreateCount = 0;
   $chunkMaxCount = %chunkcount; // At most 16 megs of data.
   
   $a = getRealTime();
   $buff = "";
   while(strlen($buff) < %buffSize)
      $buff = $buff @ "klmadskldasjkadlkjsakjlsdjksldakjlkjdlaakjlsdkljaslkjslkjdaslkjd";
   $b = getRealTime();

   $root = new TextChunk() { textData = "ROOT"; };

   $c = getRealTime();
   generateRandomChunkery($root);
   $d = getRealTime();

   echo("Created " @ $chunkCreateCount @ " chunks in " @ $chunkTestLevel @ " levels.");
   
   %file = "common/bigchunktest.chunk";
   echo("Saving to '" @ %file @ "'...");
   $e = getRealTime();
   saveChunkFile($root, %file);
   $f = getRealTime();
   echo("Done.");
   
   echo("Deleting object hierarchy...");
   $root.delete();
   echo("Done.");
   
   echo("Loading object hierarchy from '"@%file@"'...");
   $g = getRealTime();
   $newRoot = loadChunkFile(%file);
   $h = getRealTime();
   echo("Done.");
   
   echo("chunkCount = " @ $chunkCreateCount @ ", chunkSize=" @ %buffSize);
   echo("Generated data = " @ ($chunkCreateCount * %buffSize));
   echo("Elapsed time = " @ ((getRealTime() - $chunkStartTime)/1000) @ " sec.");
   echo("Buffer init  = " @ (($b-$a)/1000) @ " sec.");
   echo("chunk gen    = " @ (($d-$c)/1000) @ " sec.");
   echo("save time    = " @ (($f-$e)/1000) @ " sec.");
   echo("load time    = " @ (($h-$g)/1000) @ " sec.");
   
   return $newRoot;
}

function testchunk()
{
   %foo = 
   new TextChunk()
   {
      textData = "pony";
      
      new TextChunk()
      {
         textData = "child1";
         
      new TextChunk()
      {
         textData = "childQ";
      };
      };

      new TextChunk()
      {
         textData = "child2";
      };
      new TextChunk()
      {
         textData = "child3";

      new TextChunk()
      {
         textData = "childA";
      };

      new TextChunk()
      {
         textData = "childB";
      };

      new TextChunk()
      {
         textData = "childC";
      };

      new TextChunk()
      {
         textData = "childD";
      };

      new TextChunk()
      {
         textData = "childE";
      };
      };
    };
    
    saveChunkFile(%foo, "starter.fps/test.chunk");
    
    %foo.delete();
    
    $foo = loadChunkFile("starter.fps/test.chunk");
      
      
}
