//-----------------------------------------------------------------------------
// Torque Game Engine 
// Copyright (C) GarageGames.com, Inc.
//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------
// Hook into the mission editor.

function fxLightData::create(%data)
{
   // The mission editor invokes this method when it wants to create
   // an object of the given datablock type.
   %obj = new fxLight() {
      dataBlock = %data;
   };
   return %obj;
}


//-----------------------------------------------------------------------------

datablock fxLightData(LightHalo)
{
   category = "fxLights";
   // Dynamic light
   LightOn = true;
   Radius = 5.0;
   Brightness = 1.0;
   Colour = ".5 .5 .5";

   // Flare effect
   FlareOn = true;
   FlareTP = true;
   FlareBitmap = "core/common/lighting/corona";
   FlareColour = "1 1 0.5";
   ConstantSizeOn = false;
   ConstantSize = 0.2;
   NearSize = 1.2;
   FarSize = 0.2;
   NearDistance = 10.0;
   FarDistance = 30.0;
   FadeTime = 0.1;
   BlendMode = 0;
   LinkFlare = true;
   LinkFlareSize = false;
   
   // Brightness animation
   AnimBrightness = true;
   MinBrightness = 0.8;
   MaxBrightness = 1.0;
   BrightnessTime = 0.2;
   LerpBrightness = true;
   BrightnessKeys = "AZA";
   
   // Color animation
   AnimColour = false;
   MinColour = "0 0 0";
   MaxColour = "1 1 1";
   ColourTime = 1.0;
   LerpColour = true;
   SingleColourKeys = true;
   RedKeys = "AZA";
   GreenKeys = "AZA";
   BlueKeys = "AZA";

   // Radius animation
   AnimRadius = false;
   MinRadius = 0.1;
   MaxRadius = 20.0;
   RadiusTime = 5.0;
   LerpRadius = true;
   RadiusKeys = "AZA";
   
   // Offset animation
   AnimOffset = false;
   StartOffset = "-5 0 0";
   EndOffset = "5 0 0";
   OffsetTime = 5.0;
   LerpOffset = true;
   OffsetKeys = "AZA";
   
   // Rotation animation
   AnimRotation = false;
   MinRotation = 0;
   MaxRotation = 350;
   RotationTime = 5.0;
   LerpRotation = true;
   RotationKeys = "AZA";
};

//-----------------------------------------------------------------------------

datablock fxLightData(FlameLight)
{
   category = "fxLights";

   // Dynamic light
   LightOn = true;
   Radius = 3.0;
   Brightness = 1.0;
   Colour = "1 1 0.5";

   // Flare effect
   FlareOn = true;
   FlareTP = true;
   FlareBitmap = "core/common/lighting/corona";
   FlareColour = "1 1 0.5";
   ConstantSizeOn = false;
   ConstantSize = 0.2;
   NearSize = 0.5;
   FarSize = 0.2;
   NearDistance = 10.0;
   FarDistance = 30.0;
   FadeTime = 0.1;
   BlendMode = 0;
   LinkFlare = true;
   LinkFlareSize = false;
   
   // Brightness animation
   AnimBrightness = true;
   MinBrightness = 0.8;
   MaxBrightness = 1.0;
   BrightnessTime = 0.2;
   LerpBrightness = true;
   BrightnessKeys = "AZA";
   
   // Color animation
   AnimColour = false;
   MinColour = "0 0 0";
   MaxColour = "1 1 1";
   ColourTime = 1.0;
   LerpColour = true;
   SingleColourKeys = true;
   RedKeys = "AZA";
   GreenKeys = "AZA";
   BlueKeys = "AZA";

   // Radius animation
   AnimRadius = false;
   MinRadius = 0.1;
   MaxRadius = 20.0;
   RadiusTime = 5.0;
   LerpRadius = true;
   RadiusKeys = "AZA";
   
   // Offset animation
   AnimOffset = false;
   StartOffset = "-5 0 0";
   EndOffset = "5 0 0";
   OffsetTime = 5.0;
   LerpOffset = true;
   OffsetKeys = "AZA";
   
   // Rotation animation
   AnimRotation = false;
   MinRotation = 0;
   MaxRotation = 350;
   RotationTime = 5.0;
   LerpRotation = true;
   RotationKeys = "AZA";
};


//-----------------------------------------------------------------------------

datablock fxLightData(SoftLight)
{
   category = "fxLights";

   // Dynamic light
   LightOn = true;
   Radius = 4.0;
   Brightness = 1.0;
   Colour = "1 1 1";

   // Flare effect
   FlareOn = true;
   FlareTP = true;
   FlareBitmap = "core/common/lighting/lightFalloffMono";
   FlareColour = "1 1 1";
   ConstantSizeOn = false;
   ConstantSize = 0.2;
   NearSize = 1.2;
   FarSize = 0.2;
   NearDistance = 10.0;
   FarDistance = 30.0;
   FadeTime = 0.1;
   BlendMode = 2;
   LinkFlare = true;
   LinkFlareSize = false;

   // Brightness animation
   AnimBrightness = true;
   MinBrightness = 0.8;
   MaxBrightness = 1.0;
   BrightnessTime = 0.2;
   LerpBrightness = true;
   BrightnessKeys = "AZA";

   // Color animation
   AnimColour = false;
   MinColour = "0 0 0";
   MaxColour = "1 1 1";
   ColourTime = 1.0;
   LerpColour = true;
   SingleColourKeys = true;
   RedKeys = "AZA";
   GreenKeys = "AZA";
   BlueKeys = "AZA";

   // Radius animation
   AnimRadius = true;
   MinRadius = 2;
   MaxRadius = 3;
   RadiusTime = 10.0;
   LerpRadius = true;
   RadiusKeys = "AZA";

   // Offset animation
   AnimOffset = false;
   StartOffset = "-5 0 0";
   EndOffset = "5 0 0";
   OffsetTime = 5.0;
   LerpOffset = true;
   OffsetKeys = "AZA";

   // Rotation animation
   AnimRotation = false;
   MinRotation = 0;
   MaxRotation = 350;
   RotationTime = 5.0;
   LerpRotation = true;
   RotationKeys = "AZA";
};


//-----------------------------------------------------------------------------

datablock ParticleData(FlameSmoke)
{
   textureName          = "~/data/particles/smoke";
   dragCoefficient     = 0.0;
   gravityCoefficient   = -0.2;   // rises slowly
   windCoefficient      = 0;
   inheritedVelFactor   = 0.00;
   lifetimeMS           = 2000;
   lifetimeVarianceMS   = 250;
   useInvAlpha = false;
   spinRandomMin = -30.0;
   spinRandomMax = 30.0;

   colors[0]     = "0.6 0.6 0.6 0.1";
   colors[1]     = "0.6 0.6 0.6 0.1";
   colors[2]     = "0.6 0.6 0.6 0.0";

   sizes[0]      = 0.25;
   sizes[1]      = 0.5;
   sizes[2]      = 1.0;

   times[0]      = 0.0;
   times[1]      = 0.5;
   times[2]      = 1;
};

datablock ParticleEmitterData(FlameSmokeEmitter)
{
   ejectionPeriodMS = 40;
   periodVarianceMS = 5;

   ejectionVelocity = 0.25;
   velocityVariance = 0.10;

   thetaMin         = 0.0;
   thetaMax         = 90.0; 

   particles = FlameSmoke;
};

//-----------------------------------------------------------------------------

datablock ParticleData(LaserBeam)
{
   textureName          = "~/data/particles/dot";
   dragCoefficient     = 0.0;
   gravityCoefficient   = 0.0;
   windCoefficient      = 0.0;
   inheritedVelFactor   = 0.0;
   lifetimeMS           = 1000;
   lifetimeVarianceMS   = 0;
   useInvAlpha = true;
   spinRandomMin = 0.0;
   spinRandomMax = 0.0;

   colors[0]     = "1.0 0.0 0.0 0.7";
   colors[1]     = "1.0 0.0 0.0 0.7";
   
   sizes[0]      = 0.1;
   sizes[1]      = 0.1;

   times[0]      = 0.0;
};

datablock ParticleEmitterData(LaserBeamEmitter)
{
   ejectionPeriodMS = 25;
   periodVarianceMS = 0;

   ejectionVelocity = 50;
   velocityVariance = 0.0;

   thetaMin         = 0.0;
   thetaMax         = 0.0; 

   particles = LaserBeam;
};

//-----------------------------------------------------------------------------

datablock ParticleData(Bubbles)
{
   textureName          = "~/data/particles/bubble";
   dragCoefficient     = 0.2;
   gravityCoefficient   = 0.0;
   windCoefficient      = 0.3;
   inheritedVelFactor   = 0.4;
   lifetimeMS           = 5000;
   lifetimeVarianceMS   = 2000;
   useInvAlpha = true;
   spinRandomMin = -90.0;
   spinRandomMax = 90.0;

   colors[0]     = "1.0 1.0 1.0 0.5";
   colors[1]     = "1.0 1.0 1.0 0.5";
   colors[2]     = "1.0 1.0 1.0 0.5";
   
   sizes[0]      = 0.25;
   sizes[1]      = 0.5;
   sizes[2]      = 1.0;

   times[0]      = 0.0;
   times[1]      = 1000;
   times[2]      = 3000;
};

datablock ParticleEmitterData(BubblesEmitter)
{
   ejectionPeriodMS = 25;
   periodVarianceMS = 12;

   ejectionVelocity = 4.0;
   velocityVariance = 2.0;

   thetaMin         = 0.0;
   thetaMax         = 45.0; 

   particles = Bubbles;
};

//-----------------------------------------------------------------------------

datablock ParticleEmitterNodeData(NormalEmitterNode)
{
   timeMultiple = 1;
};
//------------------------------------------------------------------------------

//Array for fxLight Datablock names
$fxLightTot = 0;
$fxLight[$fxLightTot++] = "LightHalo";
$fxLight[$fxLightTot++] = "SoftLight";
$fxLight[$fxLightTot++] = "FlameLight";

//Array for fxLight Datablock names
$fxPartTot = 0;
$fxParticle[$fxPartTot++] = "FlameSmokeEmitter";
$fxParticle[$fxPartTot++] = "LaserBeamEmitter";
$fxParticle[$fxPartTot++] = "BubblesEmitter";

function sendClientfxData(%client)
{
   commandtoClient(%client,'clrFxData');
   
   while(%a<$fxLightTot) {
      commandtoClient(%client,'getFxData',"light",$fxLight[%a++]);        ///< Send FxLight Datablock names
   }
   while(%b<$fxPartTot)
      commandtoClient(%client,'getFxData',"particle",$fxParticle[%b++]);  ///< Send FxParticle Datablock name
   
}

// weeeheee lights
function servercmdAttachLight(%client,%db)
{
   if(%db $= "")
   {
      %client.player.selectedObj.light.delete();
      %client.player.selectedObj.light = "";
      return;  
   }
    %light = new fxLight()
    {
        datablock = %db;
    };
    %light.setTransform(%client.player.selectedObj.getTransform());
    
    if(%client.player.selectedObj.light)
       %client.player.selectedObj.light.delete();
       
    %client.player.selectedObj.light = %light;
    
    %light.attachToObject(%client.player.selectedobj);
    
    MissionCleanup.add(%light);
}

function servercmdAttachParticle(%client,%db)
{
   if(%db $= "")
   {
      %client.player.selectedObj.emitter.delete();
      %client.player.selectedObj.emitter = "";
      return;  
   }
    %emitter = new ParticleEmitterNode()
    {
       datablock = "NormalEmitterNode";
       emitter   = %db;
    };
    %emitter.setTransform(%client.player.selectedObj.getWorldBoxCenter());

    if(%client.player.selectedObj.emitter)
       %client.player.selectedObj.emitter.delete();
       echo(%emitter);
       echo(%emitter.emitter);
    %client.player.selectedObj.emitter = %emitter;
    
    MissionCleanup.add(%emitter);
}